/* * This file is part of libduicontentwidgets *
 *
 * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Otto Kopra <otto.kopra@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
#ifndef MTAGFILTERVIEW_H
#define MTAGFILTERVIEW_H

#include <QObject>
#include <MApplicationPage>
#include <QUrl>

class MTagFilterViewPrivate;

/*!
 * \class MTagFilterView mtagfilterview.h
 * \brief An application page for searching content items with tags
 *
 * MTagFilterView displays a cloud of selectable tags and location tags.
 * Selecting tags makes the filter view run a tracker query and display
 * number of content items in the toolbar button. When user presses
 * the button, signal with a list of found items is sent to calling application.
 *
 * The tag filter view chooses the tags it displays based on content type.
 * Ie, the calling application must determine whether it wants to search,
 * say, Images by tags and pass the correct nepomuk ontology type url to
 * tag filter view. The view will then display all tags that have been assigned
 * to items of the given type.
 *
 * Note that tag filter view doesn't dismiss itself when View -button is pressed.
 * The calling application must close the view explicitly.
 */
class MTagFilterView : public MApplicationPage
{
    Q_OBJECT

public:
    /*!
    * \brief Default constructor.  Creates the tag Filter view.
    * \param contentType Content type RDF class used for searching tags
    */
    MTagFilterView(const QUrl& contentType, QGraphicsItem *parent=0);

    /*!
    * \brief Default constructor.  Creates the tag Filter view.
    * \param contentType Content type RDF class used for searching tags
    * \param initialTags List of tags that should be set as selected when tag filter view opens.
    *  tags in initial tags list that are not found in contentType association query are ignored.
    */
    MTagFilterView(const QUrl& contentType, const QList<QUrl>& initialTags, QGraphicsItem *parent=0);

    /*!
    * \brief Default constructor.  Creates the tag Filter view.
    * \param contentType Content type RDF class used for searching tags
    * \param invertedColors if true, inverted colors are enabled. If false
    * inverted colors are disabled. Using the constructor without this parameter uses normal color scheme by default
    */
    MTagFilterView(const QUrl& contentType, bool invertedColors, QGraphicsItem *parent=0);

    /*!
     * \brief Destructor for MTagFilterView
     */
    ~MTagFilterView();

    /*!
     * \brief Updates tags in MTagFilterView.
     *
     * The refresh method re-runs tracker query for getting tag information. The tag filter view
     * doesn't automatically update itself in case user has edited tags in some other view. Instead,
     * the refresh function must be called explicitely.
     */
    void refresh();

    /*!
     * \brief Called by framework. Creates the tag Filter view content.
     */
    void createContent();

public slots:
    /*!
     * \brief Clears all tag selections in tag filter view.
     */
    void resetTagSelection();

    /*! Re-implemented from MApplicationPage
      */
    void dismiss();

signals:
    /*!
      * \brief Sent when user presses "View" button of  the Tag Filter view
      *
      * This signal is not sent if user presses back button in tag filter view.
      *
      * \param itemUris Results of the filtering query. Contains list of tracker uris for
      * items that are tagged with seleted tags.
      * \param tagUris List of tags that user has selected
      * \param TagLabels List of labels of tags that user has selected
      */
    void viewClosed(QList<QUrl> itemUris, QList<QUrl> tagUris, QStringList tagLabels);

protected:
    void retranslateUi();

private:
    Q_DECLARE_PRIVATE(MTagFilterView)
    MTagFilterViewPrivate* d_ptr;
    Q_DISABLE_COPY(MTagFilterView)
};

#endif // MTAGFILTERVIEW_H
