/* * This file is part of libduicontentwidgets *
 *
 * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Otto Kopra <otto.kopra@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */

#ifndef MTRANSIENTITEMTAGGINGWIDGET_H
#define MTRANSIENTITEMTAGGINGWIDGET_H

#include "mtransientitemtaggingwidgetmodel.h"

#include <QUrl>
#include <QList>
#include <QString>
#include <QStringList>
#include <QGraphicsItem>
#include <MWidgetController>

class MTransientItemTaggingWidgetPrivate;
class GeoAddress;

/*!
  * \class MTransientItemTaggingWidget mtransientitemtaggingwidget.h
  * \brief A widget to display tags associations that are not stored in tracker.
  *
  * MTransientItemTaggingWidget is intended to display tag associations
  * for content that is for some reason not indexed by tracker. In this case
  * calling application must keep track of the content items and their
  * tag associations by itself.
  *
  * MTransientItemTaggingWidget itself displays a non-interactive list of selected
  * tags. It has a link to edit view which allows user to edit tag associations via
  * identical ui as the MTagEditView. The only difference is that the changes that
  * user makes are not stored in tracker.
  *
  * All the tags displayed by MTransientItemTaggingWidget must be available
  * in tracker. Invalid url or urls with no corresponding tracker nao:Tag type object
  * are ignored.
  *
  */
class MTransientItemTaggingWidget : public MWidgetController
{
    Q_OBJECT
    M_CONTROLLER(MTransientItemTaggingWidget)

public:

    /*!
      * \brief Constructor
      */
    explicit MTransientItemTaggingWidget(QGraphicsItem* parent = 0);

    /*!
     * \brief Constructor
     * \param assignedTags List of tag labels that will be shown when tagging widget is first displayed
     */
    explicit MTransientItemTaggingWidget(const QList<QUrl>& assignedTags, QGraphicsItem* parent = 0);

    /*!
     * \brief Constructor
     * \param assignedTags List of tags that will be shown when tagging widget is first displayed
     * \param partiallyAssignedTags List of tags and their assigned item counts  that will be shown when tagging widget is first displayed
     */
    explicit MTransientItemTaggingWidget(
        const QList<QUrl>& assignedTags,
        const QMap<QUrl, int> & partiallyAssignedTags,
        QGraphicsItem* parent = 0);

    /*!
     * \brief Constructor
     * \param assignedTags List of tags that will be shown when tagging widget is first displayed
     * \param partiallyAssignedTags List of tags and their assigned item counts  that will be shown when tagging widget is first displayed
     * \param assignedGeoTags Pair of assigned geo tag info. GeoAddress keeps info of postal address entities e.g. city, country and district.
     * \param partiallyAssignedGeoTags Pair of partially assigned geo tag info. GeoAddress keeps info of postal address entities e.g. city, country and district. Int parameter keeps the number of tagged items
     * at least either assignedGeoTags or partiallyAssignedGeoTags should be always empty
     */
    explicit MTransientItemTaggingWidget(
        const QList<QUrl>& assignedTags,
        const QMap<QUrl, int>& partiallyAssignedTags,
        const GeoAddress& assignedGeoTags,
        const QList<QPair<GeoAddress, int> >& partiallyAssignedGeoTags,
        QGraphicsItem* parent = 0);

    /*!
     * \brief MTransientItemTaggingWidget destructor
     */
    virtual ~MTransientItemTaggingWidget();

   /*!
     * \brief Returns the tags that are currently selected
     * \param tagUris Tracker uris of the selected tags
     * \param tagLabels Labels of the selected tags
     */
   void getTags(QList<QUrl>& tagUris, QStringList& tagLabels);

   /*!
     * \brief Returns the tags that are currently selected
     * \param assignedTags Tracker uris of user selected tags
     * \param partiallyAssignedTags Tracker uris of partially selected tags
     */
   void getTags(QList<QUrl>& assignedTags, QList<QUrl>& partiallyAssignedTags);

   /*!
     * \brief Returns the tags that are currently selected
     * \param assignedTags Tracker uris of user selected tags
     * \param partiallyAssignedTags Tracker uris of partially selected tags
     * \param geoTags If geo tags are changed MTransientItemTaggingWidget, geoTags contains the new GeoAddress. If geo tags where not changed, geoTags will contain empty GeoAddress
     */
   void getTags(QList<QUrl>& assignedTags, QList<QUrl>& partiallyAssignedTags, GeoAddress& geoTags);

   /*!
     * \brief Returns the tags that are currently selected
     * \param assignedTags Tracker uris of user selected tags
     * \param partiallyAssignedTags Tracker uris of partially selected tags
     * \param geoTags If geo tags are changed MTransientItemTaggingWidget, geoTags contains the new GeoAddress. If geo tags where not changed, geoTags will contain empty GeoAddress
     */
   void getTags(QList<QUrl>& assignedTags, QList<QUrl>& partiallyAssignedTags, QList<QPair<GeoAddress, int> >& partiallyAssignedGeoTags);

   /*!
     * \brief Returns the tags that are currently set by user
     *
     * \param assignedTags Tracker uris of user selected tags
     * \param partiallyAssignedTags Tracker uris of partially selected tags
     * \param geoTags geotag that the user has selected. If user has not changed anything or has cleared geotags, this parameter will be empty
     * \param partiallyAssignedGeoTags Previously selected geotags. If user has changed or cleared geotags, this list will be empty.
     */
   void  getTags(QList<QUrl>& assignedTags, QList<QUrl>& partiallyAssignedTags,
                 GeoAddress& assignedGeoTags, QList<QPair<GeoAddress, int> >& partiallyAssignedGeoTags);

   /*!
     * \brief Sets the assigned tags
     *
     * Sets the list of tags that are displayed in MTransientItemTaggingView ui, and marked as
     * selected when user opens the view for editing tags.
     *
     * \param assignedTags Tracker uris of the tags that should be displayed in the widget
     */
   void setTags(const QList<QUrl>& assignedTags);

   /*!
    * \brief  Sets the assigned tags
    *
    * Sets the list of tags that are displayed in MTransientItemTaggingView ui, and marked as
    * selected when user opens the view for editing tags.
    *
    * \param assignedTags List of tags that will be shown when tagging widget is first displayed
    * \param partiallyAssignedTags List of tags and their assigned item counts  that will be shown when tagging widget is first displayed
    */
   void  setTags(const QList<QUrl>& assignedTags, const QMap<QUrl, int>& partiallyAssignedTags);

   /*!
    * \brief  Sets the assigned tags
    *
    * Sets the list of tags that are displayed in MTransientItemTaggingView ui, and marked as
    * selected when user opens the view for editing tags.
    *
    * \param assignedTags List of tags that will be shown when tagging widget is first displayed
    * \param partiallyAssignedTags List of tags and their assigned item counts  that will be shown when tagging widget is first displayed
    * \param assignedGeoTags Pair of assigned geo tag info. GeoAddress keeps info of postal address entities e.g. city, country and district.
    * \param partiallyAssignedGeoTags Pair of partially assigned geo tag info. GeoAddress keeps info of postal address entities e.g. city, country and district. Int parameter keeps the number of tagged items
    * at least either assignedGeoTags or partiallyAssignedGeoTags should be always empty
    */
   void  setTags(const QList<QUrl>& assignedTags, const QMap<QUrl, int>& partiallyAssignedTags,
                 const GeoAddress& assignedGeoTags, const QList<QPair<GeoAddress, int> >& partiallyAssignedGeoTags);

protected:
    virtual void setupModel();
    virtual void retranslateUi();

protected slots:
    void updateData(const QList<const char*>& modifications);

private:
    Q_DECLARE_PRIVATE(MTransientItemTaggingWidget)
    MTransientItemTaggingWidgetPrivate* d_ptr;

};

#endif // MTRANSIENTITEMTAGGINGWIDGET_H
